@@ -26,7 +26,7 @@ AnnotationSpecsOption = Dict[str, Any]
 
 @dataclass
 class Keybind(DataClassJsonMixin):
-    """"""
+    """ """
 
     code: str
     """"""
@@ -56,7 +56,7 @@ class PositionForMinimumBoundingBoxInsertion(DataClassJsonMixin):
 
 @dataclass
 class LabelV1BoundingBoxMetadata(DataClassJsonMixin):
-    """"""
+    """ """
 
     min_width: int
     """"""
@@ -88,7 +88,7 @@ class LabelV1BoundingBoxMetadata(DataClassJsonMixin):
 
 @dataclass
 class LabelV1SegmentationMetadata(DataClassJsonMixin):
-    """"""
+    """ """
 
     min_width: int
     """"""
@@ -105,7 +105,7 @@ class LabelV1SegmentationMetadata(DataClassJsonMixin):
 
 @dataclass
 class InternationalizationMessageMessages(DataClassJsonMixin):
-    """"""
+    """ """
 
     lang: str
     """"""
@@ -116,7 +116,7 @@ class InternationalizationMessageMessages(DataClassJsonMixin):
 
 @dataclass
 class InternationalizationMessage(DataClassJsonMixin):
-    """"""
+    """ """
 
     messages: List[InternationalizationMessageMessages]
     """"""
@@ -127,7 +127,7 @@ class InternationalizationMessage(DataClassJsonMixin):
 
 @dataclass
 class InspectionPhrase(DataClassJsonMixin):
-    """"""
+    """ """
 
     id: str
     """"""
@@ -138,7 +138,7 @@ class InspectionPhrase(DataClassJsonMixin):
 
 @dataclass
 class AnnotationSpecsHistory(DataClassJsonMixin):
-    """"""
+    """ """
 
     history_id: str
     """"""
@@ -161,7 +161,7 @@ class AnnotationSpecsHistory(DataClassJsonMixin):
 
 @dataclass
 class Color(DataClassJsonMixin):
-    """"""
+    """ """
 
     red: int
     """"""
@@ -175,7 +175,7 @@ class Color(DataClassJsonMixin):
 
 @dataclass
 class AdditionalDataDefinitionV1Choices(DataClassJsonMixin):
-    """"""
+    """ """
 
     choice_id: str
     """"""
@@ -183,80 +183,80 @@ class AdditionalDataDefinitionV1Choices(DataClassJsonMixin):
     name: InternationalizationMessage
     """"""
 
-    keybind: List[Keybind]
+    keybind: Optional[List[Keybind]]
     """"""
 
 
 @dataclass
 class AdditionalDataDefinitionV1(DataClassJsonMixin):
-    """"""
+    """ """
 
     additional_data_definition_id: str
     """"""
 
-    read_only: bool
+    read_only: Optional[bool]
     """"""
 
-    name: InternationalizationMessage
+    name: Optional[InternationalizationMessage]
     """"""
 
-    default: AdditionalDataDefaultType
+    default: Optional[AdditionalDataDefaultType]
     """"""
 
-    keybind: List[Keybind]
+    keybind: Optional[List[Keybind]]
     """"""
 
     type: AdditionalDataDefinitionType
     """"""
 
-    choices: List[AdditionalDataDefinitionV1Choices]
+    choices: Optional[List[AdditionalDataDefinitionV1Choices]]
     """"""
 
     regex: Optional[str]
     """"""
 
-    label_ids: List[str]
+    label_ids: Optional[List[str]]
     """リンク属性において、リンク先として指定可能なラベルID（空の場合制限なし）"""
 
     required: Optional[bool]
     """リンク属性において、入力を必須とするかどうか"""
 
-    metadata: Dict[str, str]
+    metadata: Optional[Dict[str, str]]
     """ユーザーが自由に登録できるkey-value型のメタデータです。 """
 
 
 @dataclass
 class AdditionalDataDefinitionV2(DataClassJsonMixin):
-    """"""
+    """ """
 
     additional_data_definition_id: str
     """"""
 
-    read_only: bool
+    read_only: Optional[bool]
     """"""
 
     name: InternationalizationMessage
     """"""
 
-    default: AdditionalDataDefaultType
+    default: Optional[AdditionalDataDefaultType]
     """"""
 
-    keybind: List[Keybind]
+    keybind: Optional[List[Keybind]]
     """"""
 
     type: AdditionalDataDefinitionType
     """"""
 
-    choices: List[AdditionalDataDefinitionV1Choices]
+    choices: Optional[List[AdditionalDataDefinitionV1Choices]]
     """"""
 
-    metadata: Dict[str, str]
+    metadata: Optional[Dict[str, str]]
     """ユーザーが自由に登録できるkey-value型のメタデータです。 """
 
 
 @dataclass
 class AnnotationEditorFeature(DataClassJsonMixin):
-    """"""
+    """ """
 
     append: bool
     """"""
@@ -279,7 +279,7 @@ class AnnotationEditorFeature(DataClassJsonMixin):
 
 @dataclass
 class LabelV1(DataClassJsonMixin):
-    """"""
+    """ """
 
     label_id: str
     """"""
@@ -308,16 +308,16 @@ class LabelV1(DataClassJsonMixin):
     annotation_editor_feature: AnnotationEditorFeature
     """"""
 
-    allow_out_of_image_bounds: bool
+    allow_out_of_image_bounds: Optional[bool]
     """"""
 
-    metadata: Dict[str, str]
+    metadata: Optional[Dict[str, str]]
     """ユーザーが自由に登録できるkey-value型のメタデータです。 """
 
 
 @dataclass
 class LabelV2(DataClassJsonMixin):
-    """"""
+    """ """
 
     label_id: str
     """"""
@@ -346,16 +346,16 @@ class LabelV2(DataClassJsonMixin):
     annotation_editor_feature: AnnotationEditorFeature
     """"""
 
-    allow_out_of_image_bounds: bool
+    allow_out_of_image_bounds: Optional[bool]
     """"""
 
-    metadata: Dict[str, str]
+    metadata: Optional[Dict[str, str]]
     """ユーザーが自由に登録できるkey-value型のメタデータです。 """
 
 
 @dataclass
 class AdditionalDataRestriction(DataClassJsonMixin):
-    """"""
+    """ """
 
     additional_data_definition_id: str
     """"""
@@ -366,7 +366,7 @@ class AdditionalDataRestriction(DataClassJsonMixin):
 
 @dataclass
 class AnnotationSpecsV1(DataClassJsonMixin):
-    """"""
+    """ """
 
     project_id: str
     """プロジェクトID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
@@ -389,7 +389,7 @@ class AnnotationSpecsV1(DataClassJsonMixin):
 
 @dataclass
 class AnnotationSpecsV2(DataClassJsonMixin):
-    """"""
+    """ """
 
     project_id: str
     """プロジェクトID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
